@@ -1,27 +1,5 @@
-############################################################################
-#
 # Copyright (C) 2022 The Qt Company Ltd.
-# Contact: https://www.qt.io/licensing/
-#
-# This file is part of Qt Creator.
-#
-# Commercial License Usage
-# Licensees holding valid commercial Qt licenses may use this file in
-# accordance with the commercial license agreement provided with the
-# Software or, alternatively, in accordance with the terms contained in
-# a written agreement between you and The Qt Company. For licensing terms
-# and conditions see https://www.qt.io/terms-conditions. For further
-# information use the contact form at https://www.qt.io/contact-us.
-#
-# GNU General Public License Usage
-# Alternatively, this file may be used under the terms of the GNU
-# General Public License version 3 as published by the Free Software
-# Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-# included in the packaging of this file. Please review the following
-# information to ensure the GNU General Public License requirements will
-# be met: https://www.gnu.org/licenses/gpl-3.0.html.
-#
-############################################################################
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
 
 def openQbsProject(projectPath):
     cleanUpUserFiles(projectPath)
@@ -168,7 +146,7 @@ def __selectQtVersionDesktop__(buildSystem, checks, available=None):
         for target in checkedTargets:
             detailsWidget = waitForObject("{type='Utils::DetailsWidget' unnamed='1' visible='1' "
                                           "summaryText='%s'}" % Targets.getStringForTarget(target))
-            detailsButton = getChildByClass(detailsWidget, "Utils::DetailsButton")
+            detailsButton = getChildByClass(detailsWidget, "QToolButton")
             if test.verify(detailsButton != None, "Verifying if 'Details' button could be found"):
                 clickButton(detailsButton)
                 cbObject = ("{type='QCheckBox' text='%s' unnamed='1' visible='1' "
